﻿namespace StructuralPatterns.Proxy.Client
{
    using System;
    using StructuralPatterns.Proxy;

    class Program
    {
        public static void ShowEmployeeInfo(int id, IEmployeeDataSource dataSource)
        {
            EmployeeInfo employeeInfo = dataSource.GetEmployeeInfo(id);
            Console.WriteLine("Employee id = {0}", employeeInfo.Id);
            Console.WriteLine("Employee name = {0}\n", employeeInfo.FullName);
        }

        public static void SetEmployeeName(int id, string fullName, IEmployeeDataSource dataSource)
        {
            EmployeeInfo employeeInfo = dataSource.GetEmployeeInfo(id);
            employeeInfo.FullName = fullName;
            dataSource.SetEmployeeInfo(employeeInfo);
        }

        public static void Main(string[] args)
        {
            bool useRemoteDB = true;
            IEmployeeDataSource dataSource = DataSourceFactory.CreateEmployeeDataSource(useRemoteDB);

            ShowEmployeeInfo(11, dataSource);
            ShowEmployeeInfo(12, dataSource);

            SetEmployeeName(11, "Employee name 1", dataSource);
            SetEmployeeName(12, "Employee name 2", dataSource);

            ShowEmployeeInfo(42, dataSource);

            ShowEmployeeInfo(11, dataSource);
            ShowEmployeeInfo(12, dataSource);

            Console.WriteLine("\nDone ...");
            Console.ReadKey(true);
        }
    }
}
